import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { scaleLog } from 'd3-scale';
import { useMemo, useRef } from 'react';
import { useLogTicks } from 'react-d3-utils';
import { usePlotContext } from '../../hooks';
import VerticalText from '../VerticalText';
import { TicksLog } from './TicksLog';
export default function RightLogAxis({ id, displayGridLines, hidden = false, label, labelSpace, labelStyle, fontSize, tickStyle, hiddenTicks = false, tickEmbedded, tickLength, hiddenSecondaryTicks, }) {
    const { axisContext, plotWidth, plotHeight } = usePlotContext();
    // Calculates the main axis values
    const { scale = scaleLog(), scientific } = axisContext[id] || {};
    const groupRef = useRef(null);
    const tickFormat = useMemo(() => (scientific ? (x) => x.toExponential(2) : undefined), [scientific]);
    const ticks = useLogTicks(scale, 'vertical', groupRef, {
        tickFormat,
    });
    const range = (scale === null || scale === void 0 ? void 0 : scale.range()) || [0, 0];
    // Create gridlines
    const gridlines = useMemo(() => {
        if (!displayGridLines || !scale)
            return null;
        return (_jsx("g", Object.assign({ className: "gridLines" }, { children: ticks.map(({ position }) => (_jsx("line", { x1: "0", x2: plotWidth, y1: position, y2: position, stroke: "black", strokeDasharray: "2,2", strokeOpacity: 0.5 }, position))) }), void 0));
    }, [displayGridLines, ticks, scale, plotWidth]);
    const tickDirection = tickEmbedded ? -1 : 1;
    const tickLen = tickDirection * tickLength;
    const tickTextPosition = tickEmbedded ? 8 : 8 + tickLen;
    return (_jsxs("g", Object.assign({ ref: groupRef, className: "axis" }, { children: [gridlines, !hidden && (_jsxs("g", Object.assign({ className: "ticks", transform: `translate(${plotWidth} 0)` }, { children: [_jsx("line", { y1: range[0], y2: range[1], stroke: "black" }, void 0),
                    _jsx(TicksLog, { hidden: hiddenTicks, ticks: ticks, style: tickStyle, hiddenSecondaryTicks: hiddenSecondaryTicks, anchor: "begin", getPositions: (y) => ({
                            line: { x2: tickLen, y1: y, y2: y },
                            text: { x1: tickTextPosition, y1: y },
                        }) }, void 0)] }), void 0)),
            label && !hidden && (_jsx(VerticalText, { label: label, dy: fontSize, fontSize: fontSize, style: labelStyle, transform: `translate(${plotWidth + fontSize + labelSpace + (scientific ? 14 : 0)}, ${plotHeight / 2})` }, void 0))] }), void 0));
}
//# sourceMappingURL=RightLogAxis.js.map