"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const hooks_1 = require("../../hooks");
const BottomAxis_1 = __importDefault(require("./BottomAxis"));
const BottomLogAxis_1 = __importDefault(require("./BottomLogAxis"));
const LeftAxis_1 = __importDefault(require("./LeftAxis"));
const LeftLogAxis_1 = __importDefault(require("./LeftLogAxis"));
const RightAxis_1 = __importDefault(require("./RightAxis"));
const RightLogAxis_1 = __importDefault(require("./RightLogAxis"));
const TopAxis_1 = __importDefault(require("./TopAxis"));
const TopLogAxis_1 = __importDefault(require("./TopLogAxis"));
function Axis({ id, position, min, max, paddingStart, paddingEnd, flip = false, scale = 'linear', 
// children props
label, fontSize = 16, labelSpace = 24, displayGridLines, labelStyle, hidden = false, tickStyle = {}, hiddenTicks, tickEmbedded, tickLength = 6, hiddenSecondaryTicks, }) {
    const { dispatch } = hooks_1.useDispatchContext();
    const xY = ['top', 'bottom'].includes(position) ? 'x' : 'y';
    react_1.useEffect(() => {
        const minPadding = paddingStart || 0;
        const maxPadding = paddingEnd || 0;
        if (minPadding < 0 || minPadding > 1) {
            throw new Error(`Padding ${position} (${minPadding}) is not between 0 and 1`);
        }
        if (maxPadding < 0 || maxPadding > 1) {
            throw new Error(`Padding ${position} (${maxPadding}) is not between 0 and 1`);
        }
        dispatch({
            type: 'newAxis',
            value: {
                id: id || xY,
                position,
                min,
                max,
                paddingStart: minPadding,
                paddingEnd: maxPadding,
                flip,
                scale,
            },
        });
        return () => dispatch({ type: 'removeAxis', value: { id: id || xY } });
    }, [
        dispatch,
        xY,
        id,
        position,
        min,
        max,
        flip,
        paddingStart,
        paddingEnd,
        scale,
    ]);
    const childProps = {
        id: id || xY,
        displayGridLines,
        hidden,
        label,
        labelSpace,
        labelStyle,
        fontSize,
        tickStyle,
        hiddenTicks,
        tickEmbedded,
        tickLength,
        hiddenSecondaryTicks,
    };
    switch (`${position}-${scale}`) {
        case 'top-log':
            return jsx_runtime_1.jsx(TopLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'top-linear':
            return jsx_runtime_1.jsx(TopAxis_1.default, Object.assign({}, childProps), void 0);
        case 'bottom-log':
            return jsx_runtime_1.jsx(BottomLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'bottom-linear':
            return jsx_runtime_1.jsx(BottomAxis_1.default, Object.assign({}, childProps), void 0);
        case 'left-log':
            return jsx_runtime_1.jsx(LeftLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'left-linear':
            return jsx_runtime_1.jsx(LeftAxis_1.default, Object.assign({}, childProps), void 0);
        case 'right-log':
            return jsx_runtime_1.jsx(RightLogAxis_1.default, Object.assign({}, childProps), void 0);
        case 'right-linear':
            return jsx_runtime_1.jsx(RightAxis_1.default, Object.assign({}, childProps), void 0);
        default:
            return null;
    }
}
exports.default = Axis;
