"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_shape_1 = require("d3-shape");
const react_1 = require("react");
const hooks_1 = require("../hooks");
const utils_1 = require("../utils");
const ErrorBars_1 = __importDefault(require("./ErrorBars"));
const ScatterSeries_1 = __importDefault(require("./ScatterSeries"));
const legendsContext_1 = require("./legendsContext");
function LineSeries(props) {
    var _a;
    const [, legendDispatch] = legendsContext_1.useLegend();
    const { colorScaler } = hooks_1.usePlotContext();
    const [id] = react_1.useState(() => props.groupId || `series-${utils_1.getNextId()}`);
    const { lineStyle = {}, displayMarker = false, displayErrorBars = false, hidden, ...otherProps } = props;
    react_1.useEffect(() => {
        var _a, _b;
        if (!hidden) {
            legendDispatch({
                type: 'ADD_LEGEND_LABEL',
                payload: {
                    id,
                    label: otherProps.label,
                    colorLine: ((_a = lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke) === null || _a === void 0 ? void 0 : _a.toString()) || colorScaler(id),
                    shape: {
                        color: ((_b = otherProps.markerStyle) === null || _b === void 0 ? void 0 : _b.fill.toString()) || colorScaler(id),
                        figure: otherProps.markerShape || 'circle',
                        hidden: !displayMarker,
                    },
                },
            });
        }
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [
        hidden,
        colorScaler,
        displayMarker,
        id,
        legendDispatch,
        lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke,
        otherProps.label,
        otherProps.markerShape,
        otherProps.markerStyle,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    if (hidden)
        return null;
    const lineProps = {
        id,
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        lineStyle,
    };
    const errorBarsProps = {
        data: props.data,
        xAxis: props.xAxis || 'x',
        yAxis: props.yAxis || 'y',
        hidden: !displayErrorBars,
        style: props.errorBarsStyle,
        capStyle: props.errorBarsCapStyle,
        capSize: props.errorBarsCapSize,
    };
    return (jsx_runtime_1.jsxs("g", { children: [jsx_runtime_1.jsx(LineSeriesRender, Object.assign({}, lineProps), void 0),
            jsx_runtime_1.jsx(ErrorBars_1.default, Object.assign({}, errorBarsProps), void 0),
            jsx_runtime_1.jsx(ScatterSeries_1.default, Object.assign({}, otherProps, { hidden: !displayMarker, groupId: id }), void 0)] }, void 0));
}
exports.default = LineSeries;
function LineSeriesRender({ id, data, xAxis, yAxis, lineStyle, }) {
    // Get scales from context
    const { axisContext, colorScaler } = hooks_1.usePlotContext();
    const [xScale, yScale] = utils_1.validateAxis(axisContext, xAxis, yAxis);
    // calculates the path to display
    const color = colorScaler(id);
    const path = react_1.useMemo(() => {
        if ([xScale, yScale].includes(undefined))
            return null;
        // Calculate line from D3
        const lineGenerator = d3_shape_1.line()
            .x((d) => xScale(d.x))
            .y((d) => yScale(d.y));
        return lineGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return jsx_runtime_1.jsx("path", { style: style, d: path, fill: "none" }, void 0);
}
