"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const ml_distance_euclidean_1 = require("ml-distance-euclidean");
const hooks_1 = require("../hooks");
const utils_1 = require("../utils");
const HORIZONTAL = ['bottom', 'top'];
function infoFromMouse(event, axisContext, stateSeries) {
    const { clientX, clientY } = event;
    const { left, top } = event.currentTarget.getBoundingClientRect();
    // Calculate coordinates
    let coordinates = {};
    for (const key in axisContext) {
        const { scale, position } = axisContext[key];
        if (HORIZONTAL.includes(position)) {
            coordinates[key] = scale.invert(clientX - left);
        }
        else {
            coordinates[key] = scale.invert(clientY - top);
        }
    }
    return {
        event,
        coordinates,
        getClosest: (method) => closestCalculation(method, coordinates, stateSeries, axisContext),
    };
}
function closestCalculation(method, coordinates, stateSeries, axisContext) {
    let series = {};
    switch (method) {
        case 'x': {
            for (const { id, x, data } of stateSeries) {
                if (data) {
                    const point = utils_1.closestPoint(data, coordinates, (point, pos) => {
                        const xVal = pos[x.axisId];
                        return xVal !== undefined ? Math.abs(point.x - xVal) : Infinity;
                    });
                    series[id] = { point, axis: [axisContext[x.axisId]] };
                }
            }
            break;
        }
        case 'y': {
            for (const { id, y, data } of stateSeries) {
                if (data) {
                    const point = utils_1.closestPoint(data, coordinates, (point, pos) => {
                        const yVal = pos[y.axisId];
                        return yVal !== undefined ? Math.abs(point.y - yVal) : Infinity;
                    });
                    series[id] = { point, axis: [axisContext[y.axisId]] };
                }
            }
            break;
        }
        case 'euclidean': {
            for (const { id, x, y, data } of stateSeries) {
                if (data) {
                    const point = utils_1.closestPoint(data, coordinates, (point, pos) => {
                        const xVal = pos[x.axisId];
                        const yVal = pos[y.axisId];
                        return xVal !== undefined || yVal !== undefined
                            ? ml_distance_euclidean_1.euclidean([point.x, point.y], [xVal, yVal])
                            : Infinity;
                    });
                    series[id] = {
                        point,
                        axis: [axisContext[x.axisId], axisContext[y.axisId]],
                    };
                }
            }
            break;
        }
        default: {
            throw new Error(`Unknown distance name: ${method}`);
        }
    }
    return series;
}
function Tracking({ onMouseMove, onClick, onMouseEnter, onMouseLeave, stateSeries, }) {
    const { axisContext, plotHeight, plotWidth } = hooks_1.usePlotContext();
    return (jsx_runtime_1.jsx("rect", { width: plotWidth, height: plotHeight, className: "tracking", style: { fillOpacity: 0 }, onClick: (event) => {
            onClick(infoFromMouse(event, axisContext, stateSeries));
        }, onMouseMove: (event) => {
            onMouseMove(infoFromMouse(event, axisContext, stateSeries));
        }, onMouseEnter: (event) => onMouseEnter === null || onMouseEnter === void 0 ? void 0 : onMouseEnter(event), onMouseLeave: (event) => onMouseLeave === null || onMouseLeave === void 0 ? void 0 : onMouseLeave(event) }, void 0));
}
exports.default = Tracking;
