"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LegendProvider = exports.useLegend = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const immer_1 = require("immer");
const react_1 = require("react");
const context = react_1.createContext(null);
function useLegend() {
    const ctx = react_1.useContext(context);
    if (!ctx) {
        throw new Error('context was not initialized');
    }
    return ctx;
}
exports.useLegend = useLegend;
const legendReducer = immer_1.produce((draft, action) => {
    switch (action.type) {
        case 'ADD_LEGEND_LABEL': {
            const { shape, ...newLegend } = action.payload;
            const index = draft.labels.findIndex(({ id }) => newLegend.id === id);
            if (index < 0) {
                draft.labels.push({ ...newLegend, shape });
            }
            else {
                draft.labels[index] = { ...newLegend, shape };
            }
            return;
        }
        case 'REMOVE_LEGEND_LABEL': {
            const { id } = action.payload;
            const index = draft.labels.findIndex((val) => val.id === id);
            if (index !== -1) {
                draft.labels.splice(index, 1);
            }
            return;
        }
        default:
            throw new Error('unreachable');
    }
});
const initialLegendState = {
    labels: [],
};
const LegendProvider = (props) => {
    const ctx = react_1.useReducer(legendReducer, initialLegendState);
    return jsx_runtime_1.jsx(context.Provider, Object.assign({ value: ctx }, { children: props.children }), void 0);
};
exports.LegendProvider = LegendProvider;
